==> OpenPatricianModel-0.7.0-RC1-sources.jar: ch/sahits/game/openpatrician/model/product/EWare.java <==
package ch.sahits.game.openpatrician.model.product;

import ch.sahits.game.openpatrician.util.PropertyLoader;
import com.google.common.base.Preconditions;
import lombok.Getter;

import java.util.Properties;
/**
 * Define the different type of wares that are produced and can be traded.
 * @author Andi Hotz, (c) Sahits GmbH, 2011
 * Created on Nov 20, 2011
 *
 */
public enum EWare implements IWare {
	/*
	 * The order of the enumation is important
	 * as it is the order as it is in the dialogs.
	 */
	/** Beer in barrels */
	BEER("beer.properties"),
	/** Iron ore in burden */
	IRONORE("ironore.properties"),
	/** Iron in barrels */
	IRON("iron.properties"),
	/** Fur in barrels */
	FUR("fur.properties"),
	/** Fish in burden */
	FISH("fish.properties"),
	/** Meat in burden */
	MEAT("meat.properties"),
	/** Grain in burden */
	GRAIN("grain.properties"),
	/** Spices in barrels */
	SPICE("spice.properties"),
	/** Hemp in burden */
	HEMP("hemp.properties"),
	/** Wood in burden */
	WOOD("wood.properties"),
	/** Honey in barrels */
	HONEY("honey.properties"),
	/** Pottery in barrels */
	POTTERY("pottery.properties"),
	/** Leather in barrels */
	LEATHER("leather.properties"),
	/** Pitch in barrels */
	PITCH("pitch.properties"),
	/** Salt in barrels */
	SALT("salt.properties"),
	/** Fish oil in barrels */
	FISH_OIL("fishoil.properties"),
	/** Cloth in barrels */
	CLOTH("cloth.properties"),
	/** Wine in barrels */
	WINE("wine.properties"),
	/** Wool in burden */
	WOOL("wool.properties"),
	/** Brick in burden */
	BRICK("brick.properties");
	/*
	 * For now the algorithm for the price is implemented here
	 * this means the price development is always the same.
	 */

	private final EWareSize size;
	@Getter
	private final int maxValueBuy;
	@Getter
	private final int minValueBuy;
	@Getter
	private final int maxValueSell;
	@Getter
	private final int minValueSell;
	@Getter
	private final int marketSaturation;
	@Getter
	private final String wareID;
	@Getter
	private final int maxBuyPriceModerate;
	@Getter
	private final int maxBuyPriceOffensive;
	@Getter
    private final int maxBuyPriceRabiat;

	/**
	 * Initialize the ware based on a configuration file
	 * @param configFileName file name of the configuration property file
	 */
	EWare(String configFileName){
		Properties props = PropertyLoader.loadProperties(configFileName);
		Preconditions.checkNotNull(props.getProperty("type"), "The property file "+configFileName+" does not contain the type property");
		Preconditions.checkNotNull(props.getProperty("sizeUnit"), "The property file "+configFileName+" does not contain the sizeUnit property");
		Preconditions.checkNotNull(props.getProperty("maxValueBuy"), "The property file "+configFileName+" does not contain the maxValueBuy property");
		Preconditions.checkNotNull(props.getProperty("minValueBuy"), "The property file "+configFileName+" does not contain the minValueBuy property");
		Preconditions.checkNotNull(props.getProperty("maxValueSell"), "The property file "+configFileName+" does not contain the maxValueSell property");
		Preconditions.checkNotNull(props.getProperty("minValueSell"), "The property file "+configFileName+" does not contain the maxValueSell property");
		Preconditions.checkNotNull(props.getProperty("localisationID"), "The property file "+configFileName+" does not contain the localisationID property");
		Preconditions.checkNotNull(props.getProperty("saturation"), "The property file "+configFileName+" does not contain the saturation property");
		size=EWareSize.valueOf(props.getProperty("sizeUnit"));
		maxValueBuy=Integer.parseInt(props.getProperty("maxValueBuy"));
		minValueBuy=Integer.parseInt(props.getProperty("minValueBuy"));
		wareID=props.getProperty("localisationID");
		marketSaturation=Integer.parseInt(props.getProperty("saturation"));
		minValueSell=Integer.parseInt(props.getProperty("minValueSell"));
		maxValueSell=Integer.parseInt(props.getProperty("maxValueSell"));
		maxBuyPriceModerate=Integer.parseInt(props.getProperty("maxBuyPriceModerate"));
		maxBuyPriceOffensive=Integer.parseInt(props.getProperty("maxBuyPriceOffensive"));
		maxBuyPriceRabiat=Integer.parseInt(props.getProperty("maxBuyPriceRabiat"));
	}

	@Override
	public final boolean isBarrelSizedWare() {
		return size == EWareSize.BARREL;
	}
	/* (non-Javadoc)
	 * @see ch.sahits.game.openpatrician.model.product.IWare#getSizeAsBarrels()
	 */
	@Override
	public final short getSizeAsBarrels(){
		return size.getRealMasurement();
	}



}

==> OpenPatricianModel-0.8.0-RC1-sources.jar: ch/sahits/game/openpatrician/model/product/EWare.java <==
package ch.sahits.game.openpatrician.model.product;

import ch.sahits.game.openpatrician.util.PropertyLoader;
import com.google.common.base.Preconditions;
import javafx.geometry.Point2D;
import lombok.Getter;

import java.util.Properties;
/**
 * Define the different type of wares that are produced and can be traded.
 * @author Andi Hotz, (c) Sahits GmbH, 2011
 * Created on Nov 20, 2011
 *
 */
public enum EWare implements IWare {
	/*
	 * The order of the enumation is important
	 * as it is the order as it is in the dialogs.
	 */
	/** Beer in barrels */
	BEER("beer.properties"),
	/** Iron ore in burden */
	IRONORE("ironore.properties"),
	/** Iron in barrels */
	IRON("iron.properties"),
	/** Fur in barrels */
	FUR("fur.properties"),
	/** Fish in burden */
	FISH("fish.properties"),
	/** Meat in burden */
	MEAT("meat.properties"),
	/** Grain in burden */
	GRAIN("grain.properties"),
	/** Spices in barrels */
	SPICE("spice.properties"),
	/** Hemp in burden */
	HEMP("hemp.properties"),
	/** Wood in burden */
	WOOD("wood.properties"),
	/** Honey in barrels */
	HONEY("honey.properties"),
	/** Pottery in barrels */
	POTTERY("pottery.properties"),
	/** Leather in barrels */
	LEATHER("leather.properties"),
	/** Pitch in barrels */
	PITCH("pitch.properties"),
	/** Salt in barrels */
	SALT("salt.properties"),
	/** Fish oil in barrels */
	FISH_OIL("fishoil.properties"),
	/** Cloth in barrels */
	CLOTH("cloth.properties"),
	/** Wine in barrels */
	WINE("wine.properties"),
	/** Wool in burden */
	WOOL("wool.properties"),
	/** Brick in burden */
	BRICK("brick.properties");
	/*
	 * For now the algorithm for the price is implemented here
	 * this means the price development is always the same.
	 */

	private final EWareSize size;
	@Getter
	private final int maxValueBuy;
	@Getter
	private final int minValueBuy;
	@Getter
	private final int maxValueSell;
	@Getter
	private final int minValueSell;
	@Getter
	private final int marketSaturationForSelling;
	@Getter
	private final int marketSaturationForBuying;
	@Getter
	private final String wareID;
	@Getter
	private final int maxBuyPriceModerate;
	@Getter
	private final int maxBuyPriceOffensive;
	@Getter
    private final int maxBuyPriceRabiat;
	@Getter
	private final double aiMaxBuyPercentage;
	@Getter
	private final int aiMaxBuyAbsolute;
	@Getter
	private final IBezierPriceCurve buyCurve;
	@Getter
	private final IBezierPriceCurve sellCurve;
	/**
	 * Initialize the ware based on a configuration file
	 * @param configFileName file name of the configuration property file
	 */
	EWare(String configFileName){
		Properties props = PropertyLoader.loadProperties(configFileName);
		Preconditions.checkNotNull(props.getProperty("type"), "The property file "+configFileName+" does not contain the type property");
		Preconditions.checkNotNull(props.getProperty("sizeUnit"), "The property file "+configFileName+" does not contain the sizeUnit property");
		Preconditions.checkNotNull(props.getProperty("maxValueBuy"), "The property file "+configFileName+" does not contain the maxValueBuy property");
		Preconditions.checkNotNull(props.getProperty("minValueBuy"), "The property file "+configFileName+" does not contain the minValueBuy property");
		Preconditions.checkNotNull(props.getProperty("maxValueSell"), "The property file "+configFileName+" does not contain the maxValueSell property");
		Preconditions.checkNotNull(props.getProperty("minValueSell"), "The property file "+configFileName+" does not contain the maxValueSell property");
		Preconditions.checkNotNull(props.getProperty("localisationID"), "The property file "+configFileName+" does not contain the localisationID property");
		Preconditions.checkNotNull(props.getProperty("saturation"), "The property file "+configFileName+" does not contain the saturation property");
		Preconditions.checkNotNull(props.getProperty("saturationBuy"), "The property file "+configFileName+" does not contain the saturationBuy property");
		Preconditions.checkNotNull(props.getProperty("maxBuyPriceModerate"), "The property file "+configFileName+" does not contain the maxBuyPriceModerate property");
		Preconditions.checkNotNull(props.getProperty("maxBuyPriceOffensive"), "The property file "+configFileName+" does not contain the maxBuyPriceOffensive property");
		Preconditions.checkNotNull(props.getProperty("maxBuyPriceRabiat"), "The property file "+configFileName+" does not contain the maxBuyPriceRabiat property");
		Preconditions.checkNotNull(props.getProperty("ai.maxBuy.percentage"), "The property file "+configFileName+" does not contain the ai.maxBuy.percentage property");
		Preconditions.checkNotNull(props.getProperty("ai.maxBuy.absolute"), "The property file "+configFileName+" does not contain the ai.maxBuy.absolute property");
		size=EWareSize.valueOf(props.getProperty("sizeUnit"));
		maxValueBuy=Integer.parseInt(props.getProperty("maxValueBuy"));
		minValueBuy=Integer.parseInt(props.getProperty("minValueBuy"));
		wareID=props.getProperty("localisationID");
		marketSaturationForSelling=Integer.parseInt(props.getProperty("saturation"));
		marketSaturationForBuying=Integer.parseInt(props.getProperty("saturationBuy"));
		minValueSell=Integer.parseInt(props.getProperty("minValueSell"));
		maxValueSell=Integer.parseInt(props.getProperty("maxValueSell"));
		maxBuyPriceModerate=Integer.parseInt(props.getProperty("maxBuyPriceModerate"));
		maxBuyPriceOffensive=Integer.parseInt(props.getProperty("maxBuyPriceOffensive"));
		maxBuyPriceRabiat=Integer.parseInt(props.getProperty("maxBuyPriceRabiat"));
		aiMaxBuyPercentage=Double.parseDouble(props.getProperty("ai.maxBuy.percentage"));
		aiMaxBuyAbsolute=Integer.parseInt(props.getProperty("ai.maxBuy.absolute"));
		Point2D buyStart = new Point2D(0, maxValueBuy);
		Point2D buyEnd = new Point2D(marketSaturationForBuying, minValueBuy);
		Point2D sellStart = new Point2D(0, maxValueSell);
		Point2D sellEnd = new Point2D(marketSaturationForSelling, minValueSell);
		int buyCp1X = Integer.parseInt(props.getProperty("buy.cp1.x"));
		int buyCp1Y = Integer.parseInt(props.getProperty("buy.cp1.y"));
		int buyCp2X = Integer.parseInt(props.getProperty("buy.cp2.x"));
		int buyCp2Y = Integer.parseInt(props.getProperty("buy.cp2.y"));
		int sellCp1X = Integer.parseInt(props.getProperty("sell.cp1.x"));
		int sellCp1Y = Integer.parseInt(props.getProperty("sell.cp1.y"));
		int sellCp2X = Integer.parseInt(props.getProperty("sell.cp2.x"));
		int sellCp2Y = Integer.parseInt(props.getProperty("sell.cp2.y"));
		Point2D buyCp1 = new Point2D(buyCp1X, buyCp1Y);
		Point2D buyCp2 = new Point2D(buyCp2X, buyCp2Y);
		Point2D sellCp1 = new Point2D(sellCp1X, sellCp1Y);
		Point2D sellCp2 = new Point2D(sellCp2X, sellCp2Y);
		buyCurve = new BezierPriceCurve(buyStart, buyCp1, buyCp2, buyEnd);
		sellCurve = new BezierPriceCurve(sellStart, sellCp1, sellCp2, sellEnd);
	}

	@Override
	public final boolean isBarrelSizedWare() {
		return size == EWareSize.BARREL;
	}
	/* (non-Javadoc)
	 * @see ch.sahits.game.openpatrician.model.product.IWare#getSizeAsBarrels()
	 */
	@Override
	public final short getSizeAsBarrels(){
		return size.getRealMasurement();
	}
}
